about summary refs log tree commit diff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog4
-rwxr-xr-xscripts/check-local-headers.sh5
2 files changed, 7 insertions, 2 deletions
diff --git a/ChangeLog b/ChangeLog
index 0b8c5110ed..48112a9ba5 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2012-11-16  Pino Toscano  <toscano.pino@tiscali.it>
+
+	* scripts/check-local-headers.sh: Ignore 'mach' headers.
+
 2012-11-16  Andrej Lajovic  <natrij@gmail.com>
 
 	[BZ #14672]
diff --git a/scripts/check-local-headers.sh b/scripts/check-local-headers.sh
index 5cc8def3e5..e744f8c74e 100755
--- a/scripts/check-local-headers.sh
+++ b/scripts/check-local-headers.sh
@@ -27,12 +27,13 @@ shopt -s nullglob
 
 # Search all dependency files for file names in the include directory.
 # There are a few system headers we are known to use.
 # These include Linux kernel headers (asm*, arch, and linux).
 exec ${AWK} -v includedir="$includedir" '
 BEGIN {
   status = 0
   exclude = "^" includedir \
-    "/(.*-.*-.*/|)(asm[-/]|arch|linux/|selinux/|gd|nss3/|c\\+\\+/|sys/(capability|sdt(|-config))\\.h|libaudit\\.h)"
+    "/(.*-.*-.*/|)(asm[-/]|arch|linux/|selinux/|mach/|gd|nss3/|c\\+\\+/|sys/(capability|sdt(|-config))\\.h|libaudit\\.h)"
 }
 /^[^ ]/ && $1 ~ /.*:/ { obj = $1 }
 {
@@ -27,12 +27,13 @@ shopt -s nullglob
 # Search all dependency files for file names in the include directory.
 # There are a few system headers we are known to use.
-# These include Linux kernel headers (asm*, arch, and linux).
+# These include Linux kernel headers (asm*, arch, and linux),
+# and Mach kernel headers (mach).
 exec ${AWK} -v includedir="$includedir" '
 BEGIN {